@@ -48,6 +48,12 @@ PROT_FOCUS_MULTIPLIER = 2.0
 TECH_COST_MULTIPLIER = 2.0
 FOCUS_CHANGE_PENALTY = 1
 
+SHIP_STRUCTURE_FACTOR = fo.getGameRules().getDouble("RULE_SHIP_STRUCTURE_FACTOR")
+SHIP_WEAPON_DAMAGE_FACTOR = fo.getGameRules().getDouble("RULE_SHIP_WEAPON_DAMAGE_FACTOR")
+FIGHTER_DAMAGE_FACTOR = fo.getGameRules().getDouble("RULE_FIGHTER_DAMAGE_FACTOR")
+PLANET_DEFENSE_FACTOR = SHIP_WEAPON_DAMAGE_FACTOR
+PLANET_SHIELD_FACTOR = SHIP_STRUCTURE_FACTOR
+
 # Colonization details
 COLONY_POD_COST = 120  # TODO Query directly from part
 OUTPOST_POD_COST = 50  # TODO Query directly from part
@@ -70,6 +76,18 @@ DRYDOCK_HAPPINESS_THRESHOLD = 5
 INVALID_ID = -1
 ALL_EMPIRES = -1
 
+
+class Tags:
+    POPULATION = "POPULATION"
+    INDUSTRY = "INDUSTRY"
+    WEAPONS = "WEAPONS"
+    RESEARCH = "RESEARCH"
+    SUPPLY = "SUPPLY"
+    ATTACKTROOPS = "ATTACKTROOPS"
+    STEALTH = "STEALTH"
+    SHIELDS = "SHIELDS"
+    FUEL = "FUEL"
+
 # </editor-fold>
 
 
@@ -83,7 +101,7 @@ POP_SIZE_MOD_MAP_MODIFIED_BY_SPECIES = {
     "environment_bonus": [0, -4, -2, 0, 3],
     "GRO_SYMBIOTIC_BIO": [0,  0,  1, 1, 1],
     "GRO_XENO_GENETICS": [0,  1,  2, 2, 0],
-    "GRO_XENO_HYBRIDS":   [0,  2,  1, 0, 0],
+    "GRO_XENO_HYBRIDS":  [0,  2,  1, 0, 0],
     "GRO_CYBORG":        [0,  2,  0, 0, 0],
 }
 
@@ -91,7 +109,7 @@ POP_SIZE_MOD_MAP_MODIFIED_BY_SPECIES = {
 #  - [[LATE_PRIORITY]] or later:
 POP_SIZE_MOD_MAP_NOT_MODIFIED_BY_SPECIES = {
     "GRO_SUBTER_HAB":  [0, 1, 1, 1, 1],
-    "CON_NDIM_STRC":  [0, 2, 2, 2, 2],
+    "CON_NDIM_STRC":   [0, 2, 2, 2, 2],
     "CON_ORBITAL_HAB": [0, 1, 1, 1, 1],
 }
 
@@ -113,6 +131,9 @@ POP_MOD_LIGHTSENSITIVE_STAR_MAP = {fo.starType.blue: -2, fo.starType.white: -1}
 # the percentage of normal population that a species with Gaseous tag has
 GASEOUS_POP_FACTOR = 0.50
 
+# the percentage of normal population that a species with MINDLESS_SPECIES tag has
+MINDLESS_POP_FACTOR = 0.50
+
 # </editor-fold>
 
 # <editor-fold desc="Detection Strengths">
@@ -143,11 +164,11 @@ STEALTH_SPECIAL_STRENGTHS = {
 BASE_PLANET_STEALTH = 5
 
 STEALTH_STRENGTHS_BY_SPECIES_TAG = {
-    "BAD_STEALTH": -PRIMARY_FOCS_STEALTH_LEVELS["LOW_STEALTH"],
-    "GOOD_STEALTH": PRIMARY_FOCS_STEALTH_LEVELS["LOW_STEALTH"],
-    "GREAT_STEALTH": PRIMARY_FOCS_STEALTH_LEVELS["MEDIUM_STEALTH"],
-    "ULTIMATE_STEALTH": PRIMARY_FOCS_STEALTH_LEVELS["HIGH_STEALTH"],
-    "INFINITE_STEALTH": 500,  # used by super testers
+    "BAD": -PRIMARY_FOCS_STEALTH_LEVELS["LOW_STEALTH"],
+    "GOOD": PRIMARY_FOCS_STEALTH_LEVELS["LOW_STEALTH"],
+    "GREAT": PRIMARY_FOCS_STEALTH_LEVELS["MEDIUM_STEALTH"],
+    "ULTIMATE": PRIMARY_FOCS_STEALTH_LEVELS["HIGH_STEALTH"],
+    "INFINITE": 500,  # used by super testers
 }
 # </editor-fold>
 
@@ -210,12 +231,12 @@ POP_PROPORTIONAL_MOD_SPECIALS = {
 # </editor-fold>
 
 # <editor-fold desc="Industry related specials">
-HONEYCOMB_IND_MULTIPLIER = 2.5
+HONEYCOMB_IND_MULTIPLIER = 1.0
 # </editor-fold>
 
 # <editor-fold desc="Research related specials">
 COMPUTRONIUM_SPECIAL = "COMPUTRONIUM_SPECIAL"
-COMPUTRONIUM_RES_MULTIPLIER = 1.0
+COMPUTRONIUM_RES_MULTIPLIER = 0.5
 
 ANCIENT_RUINS_SPECIAL = "ANCIENT_RUINS_SPECIAL"
 # </editor-fold>
@@ -239,6 +260,14 @@ PANOPTICON_SPECIAL = "PANOPTICON_SPECIAL"
 PANOPTICON_DETECTION_BONUS = 10
 # </editor-fold>
 
+# <editor-fold desc="Native Tech/Defense related specials">
+# (special_name, defense&shield_bonus)
+TECH_NATIVE_SPECIALS = {
+    "MODERATE_TECH_NATIVES_SPECIAL": {'defense': 10, 'shield': 10},
+    "HIGH_TECH_NATIVES_SPECIAL": {'defense': 30, 'shield': 30},
+}
+# </editor-fold>
+
 
 # </editor-fold>
 
@@ -251,10 +280,12 @@ PRO_ORBITAL_GEN = "PRO_ORBITAL_GEN"
 PRO_SOL_ORB_GEN = "PRO_SOL_ORB_GEN"
 PRO_MICROGRAV_MAN = "PRO_MICROGRAV_MAN"
 PRO_SINGULAR_GEN = "PRO_SINGULAR_GEN"
-PROD_AUTO_NAME = "PRO_SENTIENT_AUTOMATION"
+PRO_AUTO_1 = "PRO_ADAPTIVE_AUTOMATION"
+PRO_AUTO_2 = "PRO_SENTIENT_AUTOMATION"
 NEST_DOMESTICATION_TECH = "SHP_DOMESTIC_MONSTER"
 
-ART_MINDS = "LRN_ARTIF_MINDS"
+LRN_ARTIF_MINDS_1 = "LRN_NASCENT_AI"
+LRN_ARTIF_MINDS_2 = "LRN_ARTIF_MINDS"
 LRN_ALGO_ELEGANCE = "LRN_ALGO_ELEGANCE"
 GRO_PLANET_ECOL = "GRO_PLANET_ECOL"
 GRO_SUBTER_HAB = "GRO_SUBTER_HAB"
@@ -288,19 +319,24 @@ supply_range_techs = {
 # </editor-fold>
 
 # <editor-fold desc="Industry bossting techs">
+# Industry flat modifiers - [[VERY_LATE_PRIORITY]]: Not affected by species modifiers
+INDUSTRY_EFFECTS_FLAT_NOT_MODIFIED_BY_SPECIES = {
+    PRO_AUTO_1: 2,
+    PRO_AUTO_2: 3,
+}
 # Industry modifiers per population - [[EARLY_PRIORITY]]: Affected by species modifiers
 INDUSTRY_EFFECTS_PER_POP_MODIFIED_BY_SPECIES = {
-    "PRO_FUSION_GEN": 1.0,
-    "GRO_ENERGY_META": 1.0,
-    "PRO_INDUSTRY_CENTER_I": 1.0,
-    "PRO_INDUSTRY_CENTER_II": 1.0,
-    "PRO_INDUSTRY_CENTER_III": 1.0,
+    "PRO_FUSION_GEN": 0.25,
+    "GRO_ENERGY_META": 0.5,
+    "PRO_INDUSTRY_CENTER_I": 0.25,
+    "PRO_INDUSTRY_CENTER_II": 0.25,
+    "PRO_INDUSTRY_CENTER_III": 0.25,
 }
 # Industry modifiers per population - [[LATE_PRIORITY]] or later: Not affected by species modifiers
 INDUSTRY_EFFECTS_PER_POP_NOT_MODIFIED_BY_SPECIES = {
-    "PRO_ROBOTIC_PROD": 0.5,
-    "PRO_SOL_ORB_GEN": 2.0,  # TODO don't assume will build a gen at a blue/white star
-    PRO_SINGULAR_GEN: 5.0,
+    "PRO_ROBOTIC_PROD": 0.25,
+    "PRO_SOL_ORB_GEN": 0.75,  # TODO don't assume will build a gen at a blue/white star
+    PRO_SINGULAR_GEN: 1.0,
 }
 # </editor-fold>
 
@@ -332,17 +368,32 @@ DEFENSE_SHIELDS_TECHS = [
 ]
 # </editor-fold>
 
+# <editor-fold desc="Fuel techs">
+FUEL_TANK_UPGRADE_DICT = {
+    # "PARTNAME": tuple((tech_name, fuel_upgrade), (tech_name2, fuel_upgrade2), ...)
+    "FU_BASIC_TANK": (("SHP_DEUTERIUM_TANK", 0.5), ("SHP_ANTIMATTER_TANK", 1.5)),
+    "FU_RAMSCOOP": (),
+    "FU_ZERO_FUEL": (),
+}
+
+# DO NOT TOUCH THIS ENTRY BUT UPDATE FUEL_TANK_UPGRADE_DICT INSTEAD!
+FUEL_UPGRADE_TECHS = frozenset(tech_name for _dict in (FUEL_TANK_UPGRADE_DICT, )
+                               for tups in _dict.values() for (tech_name, _) in tups)
+# </editor-fold>
+
 # <editor-fold desc="Weapon techs">
 # TODO (Morlic): Consider using only 1 dict with (capacity, secondaryStat) tuple as entries
-WEAPON_UPGRADE_DICT = {
-    # "PARTNAME": tuple((tech_name, dmg_upgrade), (tech_name2, dmg_upgrade2), ...)
-    "SR_WEAPON_0_1": (),
-    "SR_WEAPON_1_1": tuple(("SHP_WEAPON_1_%d" % i, 1) for i in [2, 3, 4]),
-    "SR_WEAPON_2_1": tuple(("SHP_WEAPON_2_%d" % i, 2) for i in [2, 3, 4]),
-    "SR_WEAPON_3_1": tuple(("SHP_WEAPON_3_%d" % i, 3) for i in [2, 3, 4]),
-    "SR_WEAPON_4_1": tuple(("SHP_WEAPON_4_%d" % i, 5) for i in [2, 3, 4]),
-    "SR_SPINAL_ANTIMATTER": (),
-}
+WEAPON_UPGRADE_DICT = {part_name: tuple({tech_name: damage * SHIP_WEAPON_DAMAGE_FACTOR for tech_name, damage, in techs_damage.items()}.items()) for part_name, techs_damage in {
+    # Output "PARTNAME": tuple((tech_name, dmg_upgrade), (tech_name2, dmg_upgrade2), ...)
+    #  Input "PARTNAME": {tech_name: dmg_upgrade, tech_name2, dmg_upgrade2, ...}
+    "SR_WEAPON_0_1": {},
+    "SR_WEAPON_1_1": {"SHP_WEAPON_1_%d" % i: 1 for i in [2, 3, 4]},
+    "SR_WEAPON_2_1": {"SHP_WEAPON_2_%d" % i: 2 for i in [2, 3, 4]},
+    "SR_WEAPON_3_1": {"SHP_WEAPON_3_%d" % i: 3 for i in [2, 3, 4]},
+    "SR_WEAPON_4_1": {"SHP_WEAPON_4_%d" % i: 5 for i in [2, 3, 4]},
+    "SR_ARC_DISRUPTOR": {"SHP_WEAPON_ARC_DISRUPTOR_%d" % i: i for i in [2, 3]},
+    "SR_SPINAL_ANTIMATTER": {},
+}.items()}
 
 WEAPON_ROF_UPGRADE_DICT = {
     # "PARTNAME": tuple((tech_name, rof_upgrade), (tech_name2, rof_upgrade2), ...)
@@ -351,27 +402,32 @@ WEAPON_ROF_UPGRADE_DICT = {
     "SR_WEAPON_2_1": (),
     "SR_WEAPON_3_1": (),
     "SR_WEAPON_4_1": (),
+    "SR_ARC_DISRUPTOR": (),
     "SR_SPINAL_ANTIMATTER": (),
 }
 
-FIGHTER_DAMAGE_UPGRADE_DICT = {
-    # "PARTNAME": tuple((tech_name, dmg_upgrade), (tech_name2, dmg_upgrade2), ...)
-    "FT_HANGAR_1": (("SHP_FIGHTERS_2", 1), ("SHP_FIGHTERS_3", 1), ("SHP_FIGHTERS_4", 1)),
-    "FT_HANGAR_2": (("SHP_FIGHTERS_2", 2), ("SHP_FIGHTERS_3", 3), ("SHP_FIGHTERS_4", 5)),
-    "FT_HANGAR_3": (("SHP_FIGHTERS_2", 3), ("SHP_FIGHTERS_3", 4), ("SHP_FIGHTERS_4", 7)),
-    "FT_HANGAR_4": (),
-}
+FIGHTER_DAMAGE_UPGRADE_DICT = {part_name: tuple({tech_name: damage * FIGHTER_DAMAGE_FACTOR for tech_name, damage, in techs_damage.items()}.items()) for part_name, techs_damage in {
+    # Output "PARTNAME": tuple((tech_name, dmg_upgrade), (tech_name2, dmg_upgrade2), ...)
+    #  Input "PARTNAME": {tech_name: dmg_upgrade, tech_name2: dmg_upgrade2, ...}
+    "FT_HANGAR_1": {"SHP_FIGHTERS_2": 0, "SHP_FIGHTERS_3": 0, "SHP_FIGHTERS_4": 0},
+    "FT_HANGAR_2": {"SHP_FIGHTERS_2": 2, "SHP_FIGHTERS_3": 2, "SHP_FIGHTERS_4": 2},
+    "FT_HANGAR_3": {"SHP_FIGHTERS_2": 3, "SHP_FIGHTERS_3": 3, "SHP_FIGHTERS_4": 3},
+    "FT_HANGAR_4": {"SHP_FIGHTERS_2": 6, "SHP_FIGHTERS_3": 6, "SHP_FIGHTERS_4": 6},
+}.items()}
 
 FIGHTER_CAPACITY_UPGRADE_DICT = {
     # "PARTNAME": tuple((tech_name, capacity_upgrade), (tech_name2, capacity_upgrade2), ...)
-    "FT_HANGAR_1": (),
+    "FT_HANGAR_1": (("SHP_FIGHTERS_2", 1), ("SHP_FIGHTERS_3", 1), ("SHP_FIGHTERS_4", 1)),
     "FT_HANGAR_2": (),
     "FT_HANGAR_3": (),
     "FT_HANGAR_4": (),
 }
 
 # DO NOT TOUCH THIS ENTRY BUT UPDATE WEAPON_UPGRADE_DICT INSTEAD!
-WEAPON_UPGRADE_TECHS = [tech_name for tups in WEAPON_UPGRADE_DICT.values() for (tech_name, _) in tups]
+WEAPON_UPGRADE_TECHS = frozenset(tech_name for _dict in (WEAPON_UPGRADE_DICT, WEAPON_ROF_UPGRADE_DICT)
+                                 for tups in _dict.values() for (tech_name, _) in tups)
+FIGHTER_UPGRADE_TECHS = frozenset(tech_name for _dict in (FIGHTER_DAMAGE_UPGRADE_DICT, FIGHTER_CAPACITY_UPGRADE_DICT)
+                                  for tups in _dict.values() for (tech_name, _) in tups)
 # </editor-fold>
 
 # <editor-fold desc="Tech Groups for Automated Research Approach">
@@ -446,6 +502,7 @@ DEFENSE_TECHS_PREFIX = "DEF"
 PRODUCTION_BOOST_TECHS = (
     "PRO_ROBOTIC_PROD",
     "PRO_FUSION_GEN",
+    "PRO_ADAPTIVE_AUTOMATION",
     "PRO_SENTIENT_AUTOMATION",
     "PRO_INDUSTRY_CENTER_I",
     "PRO_INDUSTRY_CENTER_II",
@@ -454,7 +511,8 @@ PRODUCTION_BOOST_TECHS = (
 )
 RESEARCH_BOOST_TECHS = (
     "LRN_ALGO_ELEGANCE",
-    "LRN_ARTIF_MINDS",
+    LRN_ARTIF_MINDS_1,
+    LRN_ARTIF_MINDS_2,
     "LRN_PHYS_BRAIN",
     "LRN_DISTRIB_THOUGHT",
     "LRN_QUANT_NET",
@@ -596,13 +654,14 @@ SHIP_TECHS_REQUIRING_BLACK_HOLE = (
 
 # <editor-fold desc="Species">
 # species names
-SP_LAMBALALAM = "SP_LEMBALALAM"
+SP_LEMBALALAM = "SP_LEMBALALAM"
 
 # Species modifiers
 SPECIES_RESEARCH_MODIFIER = {'NO': 0.0, 'BAD': 0.75, 'GOOD': 1.5, 'GREAT': 2.0, 'ULTIMATE': 3.0}
 SPECIES_INDUSTRY_MODIFIER = {'NO': 0.0, 'BAD': 0.75, 'GOOD': 1.5, 'GREAT': 2.0, 'ULTIMATE': 3.0}
 SPECIES_POPULATION_MODIFIER = {'BAD': 0.75, 'GOOD': 1.25}
 SPECIES_SUPPLY_MODIFIER = {'VERY_BAD': -1, 'BAD': 0, 'AVERAGE': 1, 'GREAT': 2, 'ULTIMATE': 3}
+SPECIES_FUEL_MODIFIER = {'NO': -100, 'BAD': -0.5, 'AVERAGE': 0, 'GOOD': 0.5, 'GREAT': 1, 'ULTIMATE': 1.5}
 
 # <editor-fold desc="XenoResurrectionSpecies">
 EXTINCT_SPECIES = [
@@ -634,11 +693,12 @@ PILOT_ROF_MODIFIER_DICT = {
 
 PILOT_FIGHTERDAMAGE_MODIFIER_DICT = {
     # TRAIT:    {hangar_name: effect, hangar_name2: effect2,...}
+    # TODO FT_HANGAR_1 fighters are not able to attack ships so pilot damage modifier does not apply
     "NO":       {},
-    "BAD":      {"FT_HANGAR_1": -1, "FT_HANGAR_2": -2, "FT_HANGAR_3": -3, "FT_HANGAR_4": -4},
-    "GOOD":     {"FT_HANGAR_1":  1, "FT_HANGAR_2":  2, "FT_HANGAR_3":  3, "FT_HANGAR_4": 4},
-    "GREAT":    {"FT_HANGAR_1":  2, "FT_HANGAR_2":  4, "FT_HANGAR_3":  6, "FT_HANGAR_4": 8},
-    "ULTIMATE": {"FT_HANGAR_1":  3, "FT_HANGAR_2":  6, "FT_HANGAR_3":  9, "FT_HANGAR_4": 12},
+    "BAD":      {"FT_HANGAR_1":  0, "FT_HANGAR_2": -1, "FT_HANGAR_3": -1, "FT_HANGAR_4": -1},
+    "GOOD":     {"FT_HANGAR_1":  0, "FT_HANGAR_2":  1, "FT_HANGAR_3":  1, "FT_HANGAR_4": 1},
+    "GREAT":    {"FT_HANGAR_1":  0, "FT_HANGAR_2":  2, "FT_HANGAR_3":  2, "FT_HANGAR_4": 2},
+    "ULTIMATE": {"FT_HANGAR_1":  0, "FT_HANGAR_2":  3, "FT_HANGAR_3":  3, "FT_HANGAR_4": 3},
 }
 
 PILOT_FIGHTER_CAPACITY_MODIFIER_DICT = {
@@ -649,6 +709,11 @@ PILOT_FIGHTER_CAPACITY_MODIFIER_DICT = {
     "GREAT":    {},
     "ULTIMATE": {},
 }
+
+HANGAR_LAUNCH_CAPACITY_MODIFIER_DICT = {
+    # hangar_name: {bay_name: ((tech_name, effect), ...), bay_name2: ((tech_name, effect), ...}
+    "FT_HANGAR_1": {"FT_BAY_1": (("SHP_FIGHTERS_1", 1), ("SHP_FIGHTERS_2", 1), ("SHP_FIGHTERS_3", 1), ("SHP_FIGHTERS_4", 1))},
+}
 # </editor-fold>
 
 # <editor-fold desc="Extraordinary Species Rules">
@@ -658,13 +723,13 @@ TAG_DESTROYED_ON_CONQUEST = "DESTROYED_ON_CONQUEST"
 # some species have a fixed population
 SPECIES_FIXED_POPULATION = {
     # species_name: fixed_population_size
-    SP_LAMBALALAM: 5.0,
+    SP_LEMBALALAM: 5.0,
 }
 
 # techs that are unlocked if conquering a planet of a species
 SPECIES_TECH_UNLOCKS = {
     # species: [tech1, tech2, ...]
-    SP_LAMBALALAM: [GRO_LIFE_CYCLE, SPY_STEALTH_1, SPY_STEALTH_2]
+    SP_LEMBALALAM: [GRO_LIFE_CYCLE, SPY_STEALTH_1, SPY_STEALTH_2]
 }
 # </editor-fold>
 
@@ -728,6 +793,46 @@ SYSTEM_SHIP_FACILITIES = frozenset((
 # <editor-fold desc="Shipdesign/-parts">
 PART_KRILL_SPAWNER = "SP_KRILL_SPAWNER"
 
+
+HULL_EXCLUDED_SHIP_PART_CLASSES = {
+    "SH_COLONY_BASE": (fo.shipPartClass.fuel, fo.shipPartClass.speed)
+}
+
+
+# <editor-fold desc="Allowed Combat Targets">
+# TODO: Inherit from enum.Flag after switch to Python 3.6+
+class CombatTarget:
+    NONE = 0
+    SHIP = 1 << 0
+    PLANET = 1 << 1
+    FIGHTER = 1 << 2
+    ANY = SHIP | PLANET | FIGHTER
+
+    # map from weapon to allowed targets
+    PART_ALLOWED_TARGETS = {
+        "SR_WEAPON_0_1": FIGHTER,
+        "SR_WEAPON_1_1": SHIP | PLANET,
+        "SR_WEAPON_2_1": SHIP | PLANET,
+        "SR_WEAPON_3_1": SHIP | PLANET,
+        "SR_WEAPON_4_1": SHIP | PLANET,
+        "SR_SPINAL_ANTIMATTER": SHIP | PLANET,
+        "FT_HANGAR_0": NONE,
+        "FT_HANGAR_1": FIGHTER,
+        "FT_HANGAR_2": SHIP | FIGHTER,
+        "FT_HANGAR_3": SHIP,
+        "FT_HANGAR_4": SHIP | PLANET,
+        # monster weapons
+        "SR_ARC_DISRUPTOR": ANY,
+        "SR_ICE_BEAM": ANY,
+        "SR_JAWS": ANY,
+        "SR_PLASMA_DISCHARGE": ANY,
+        "SR_SPINES": ANY,
+        "SR_TENTACLE": ANY,
+        "FT_HANGAR_KRILL": SHIP | FIGHTER,
+    }
+# </editor-fold>
+
+
 # <editor-fold desc="Effect Scripting for Shipdesigns">
 # <editor-fold desc="Tokens">
 # known tokens the AI can handle
@@ -738,6 +843,7 @@ ASTEROID_STEALTH = "ASTEROID_STEALTH"
 SOLAR_STEALTH = "SOLAR_STEALTH"
 SPEED = "SPEED"
 FUEL = "FUEL"
+FUEL_EFFICIENCY = "FUEL_EFFICIENCY"
 SHIELDS = "SHIELDS"
 STRUCTURE = "STRUCTURE"
 DETECTION = "DETECTION"            # do only specify for hulls if irregular detection
@@ -752,19 +858,38 @@ BASE_DETECTION = 25
 
 TECH_EFFECTS = {
     # "TECHNAME": { Token1: Value1, Token2: Value2, ...}
-    "SHP_REINFORCED_HULL": {STRUCTURE: 5},
-    "SHP_BASIC_DAM_CONT": {REPAIR_PER_TURN: 1},
+    "SHP_REINFORCED_HULL": {STRUCTURE: 5 * SHIP_STRUCTURE_FACTOR},
+    "SHP_BASIC_DAM_CONT": {REPAIR_PER_TURN: SHIP_STRUCTURE_FACTOR},
     "SHP_FLEET_REPAIR": {REPAIR_PER_TURN: (STRUCTURE, 0.1)},  # 10% of max structure
     "SHP_ADV_DAM_CONT": {REPAIR_PER_TURN: (STRUCTURE, 0.1)},  # 10% of max structure
     "SHP_INTSTEL_LOG": {SPEED: 20},  # technically not correct, but as approximation good enough...
-    "GRO_ENERGY_META": {FUEL: 2},
+    "GRO_ENERGY_META": {FUEL: 1},
+}
+
+DEFAULT_FUEL_EFFICIENCY = 1
+HULL_TAG_EFFECTS = {
+    "GREAT_FUEL_EFFICIENCY": {
+        FUEL_EFFICIENCY: 4,
+    },
+    "GOOD_FUEL_EFFICIENCY": {
+        FUEL_EFFICIENCY: 2,
+    },
+    "AVERAGE_FUEL_EFFICIENCY": {
+        FUEL_EFFICIENCY: 1,
+    },
+    "BAD_FUEL_EFFICIENCY": {
+        FUEL_EFFICIENCY: 0.6,
+    },
 }
 
 HULL_EFFECTS = {
     # "HULLNAME": { Token1: Value1, Token2: Value2, ...}
     # Robotic line
     "SH_ROBOTIC": {
-        REPAIR_PER_TURN: 2,
+        REPAIR_PER_TURN: 2 * SHIP_STRUCTURE_FACTOR,
+    },
+    "SH_SPACE_FLUX_BUBBLE": {
+        STEALTH_MODIFIER: -30,
     },
     "SH_SPATIAL_FLUX": {
         STEALTH_MODIFIER: -30,
@@ -796,56 +921,56 @@ HULL_EFFECTS = {
     },
     "SH_MINIASTEROID_SWARM": {
         ASTEROID_STEALTH: 20,
-        SHIELDS: 5,
+        SHIELDS: 5 * SHIP_WEAPON_DAMAGE_FACTOR,
     },
     "SH_SCATTERED_ASTEROID": {
         ASTEROID_STEALTH: 40,
-        SHIELDS: 3,
+        SHIELDS: 3 * SHIP_WEAPON_DAMAGE_FACTOR,
     },
     # Organic line
     "SH_ORGANIC": {
-        REPAIR_PER_TURN: 2,
+        REPAIR_PER_TURN: 2 * SHIP_STRUCTURE_FACTOR,
         FUEL_PER_TURN: 0.2,
         DETECTION: 10,
-        ORGANIC_GROWTH: (0.2, 5),
+        ORGANIC_GROWTH: (0.2 * SHIP_STRUCTURE_FACTOR, 5 * SHIP_STRUCTURE_FACTOR),
     },
     "SH_ENDOMORPHIC": {
         DETECTION: 50,
-        ORGANIC_GROWTH: (0.5, 15),
+        ORGANIC_GROWTH: (0.5 * SHIP_STRUCTURE_FACTOR, 15 * SHIP_STRUCTURE_FACTOR),
     },
     "SH_SYMBIOTIC": {
-        REPAIR_PER_TURN: 2,
+        REPAIR_PER_TURN: 2 * SHIP_STRUCTURE_FACTOR,
         FUEL_PER_TURN: 0.2,
         DETECTION: 50,
-        ORGANIC_GROWTH: (0.2, 10),
+        ORGANIC_GROWTH: (0.2 * SHIP_STRUCTURE_FACTOR, 10 * SHIP_STRUCTURE_FACTOR),
     },
     "SH_PROTOPLASMIC": {
-        REPAIR_PER_TURN: 2,
+        REPAIR_PER_TURN: 2 * SHIP_STRUCTURE_FACTOR,
         FUEL_PER_TURN: 0.2,
         DETECTION: 50,
-        ORGANIC_GROWTH: (0.5, 25),
+        ORGANIC_GROWTH: (0.5 * SHIP_STRUCTURE_FACTOR, 25 * SHIP_STRUCTURE_FACTOR),
     },
     "SH_ENDOSYMBIOTIC": {
-        REPAIR_PER_TURN: 2,
+        REPAIR_PER_TURN: 2 * SHIP_STRUCTURE_FACTOR,
         FUEL_PER_TURN: 0.2,
         DETECTION: 50,
-        ORGANIC_GROWTH: (0.5, 15),
+        ORGANIC_GROWTH: (0.5 * SHIP_STRUCTURE_FACTOR, 15 * SHIP_STRUCTURE_FACTOR),
     },
     "SH_RAVENOUS": {
         DETECTION: 75,
-        ORGANIC_GROWTH: (0.5, 20),
+        ORGANIC_GROWTH: (0.5 * SHIP_STRUCTURE_FACTOR, 20 * SHIP_STRUCTURE_FACTOR),
     },
     "SH_BIOADAPTIVE": {
         REPAIR_PER_TURN: (STRUCTURE, 1),
         FUEL_PER_TURN: 0.2,
         DETECTION: 75,
-        ORGANIC_GROWTH: (0.5, 25),
+        ORGANIC_GROWTH: (0.5 * SHIP_STRUCTURE_FACTOR, 25 * SHIP_STRUCTURE_FACTOR),
     },
     "SH_SENTIENT": {
-        REPAIR_PER_TURN: 2,
+        REPAIR_PER_TURN: 2 * SHIP_STRUCTURE_FACTOR,
         FUEL_PER_TURN: 0.2,
         DETECTION: 70,
-        ORGANIC_GROWTH: (1, 45),
+        ORGANIC_GROWTH: (1 * SHIP_STRUCTURE_FACTOR, 45 * SHIP_STRUCTURE_FACTOR),
         STEALTH_MODIFIER: 20,
     },
     # Energy Line
